<?php

/**
 * @brief		(NE) Box of tricks Application Class
 * @author		<a href='https://invisioncommunity.com/profile/35662-nathan-explosion/'>Nathan Explosion</a>
 * @copyright	(c) 2023 Nathan Explosion
 * @package		Invision Community
 * @subpackage	(NE) Box of tricks
 * @since		14 Apr 2023
 * @version		
 */

namespace IPS\neappboxoftricks;

/**
 * (NE) Box of tricks Application Class
 */
class _Application extends \IPS\Application {

    protected function get__icon() {
        return 'bomb';
    }

    public function installOther() {
        $installedPluginsData = iterator_to_array(\IPS\Db::i()->select('plugin_id,plugin_location,plugin_enabled', 'core_plugins', array())->setKeyField('plugin_location'));
        if (\count($installedPluginsData) > 0) {
            $toBeDeleted = array();
            //We have installed plugins...let's check if any are mine!!
            $myPlugins = array(
                'neicanhazprofilephotonothamburger',
                'neunreadiconforforumcategories',
                'neclicktoviewpassword',
                'neviewpasswordonstandardlogin',
                'neuse_development_buildsreminder',
                'neoverrideallactivityasdefaultstream',
                'nemanagecreatenewstreampermissions',
                'neorderdatabasesincreatemenu',
                'nememberdeletioncontent',
                'nechangecodedefaultlanguage',
                'neadditionalpagesmediatypes',
                'neremovenewslettersfromnotificationsettings',
                'nesiteurl'
            );
            //List of specific settings to migrate from plugin version
            $myPluginsMigrateSettings = array(
                'neclicktoviewpassword' => array(
                    'neplugin_showpassword_edge' => 'neapp_boxoftricks_ctvp_edge'
                ),
                'neviewpasswordonstandardlogin' => array(
                    'neplugin_showpassword_edge' => 'neapp_boxoftricks_ctvp_edge'
                ),
                'neunreadiconforforumcategories' => array(
                    'neunreadcategories_icon_location' => 'neapp_boxoftricks_uiffc_icon_location'
                ),
                'neoverrideallactivityasdefaultstream' => array(
                    'neplugin_activitystream_homepage' => 'neapp_boxoftricks_oaaads_homepage'
                ),
                'nemanagecreatenewstreampermissions' => array(
                    'neplugin_createstreampermissions_groups' => 'neapp_boxoftricks_mcnsp_groups'
                ),
                'neorderdatabasesincreatemenu' => array(
                    'nepluginorderdatabases_myorder' => 'neapp_boxoftricks_cmsmenu_order'
                ),
                'nememberdeletioncontent' => array(
                    'neplugin_member_deletion_content_default' => 'neapp_boxoftricks_mdcd_setting'
                ),
                'nechangecodedefaultlanguage' => array(
                    'neplugin_codedefault_language' => 'neapp_boxoftricks_ccdl_default'
                ),
                'neadditionalpagesmediatypes' => array(
                    'neplugin_cmsmediatype_extra' => 'neapp_boxoftricks_cmsmediatype_extra'
                )
            );
            $myPluginsEnableNew = array(
                'neicanhazprofilephotonothamburger' => 'neapp_boxoftricks_settings_enable_ichpp',
                'neviewpasswordonstandardlogin' => 'neapp_boxoftricks_settings_enable_ctvp',
                'neclicktoviewpassword' => 'neapp_boxoftricks_settings_enable_ctvp',
                'neunreadiconforforumcategories' => 'neapp_boxoftricks_settings_enable_uiffc',
                'neuse_development_buildsreminder' => 'neapp_boxoftricks_settings_enable_udbr',
                'neoverrideallactivityasdefaultstream' => 'neapp_boxoftricks_settings_enable_oaaads',
                'nemanagecreatenewstreampermissions' => 'neapp_boxoftricks_settings_enable_mcnsp',
                'neorderdatabasesincreatemenu' => 'neapp_boxoftricks_settings_enable_cmsmenu',
                'nememberdeletioncontent' => 'neapp_boxoftricks_settings_enable_mdcd',
                'nechangecodedefaultlanguage' => 'neapp_boxoftricks_settings_enable_ccdl',
                'neadditionalpagesmediatypes' => 'neapp_boxoftricks_settings_enable_cmsmediatype',
                'neremovenewslettersfromnotificationsettings' => 'neapp_boxoftricks_settings_enable_rnfns',
                'nesiteurl' => 'neapp_boxoftricks_settings_enable_siteurl'
            );
            foreach ($myPlugins as $myPluginK => $myPluginV) {
                if (ISSET($installedPluginsData[$myPluginV])) {
                    //We've got one...let's do stuff
                    $setting = '';
                    //Is it enabled? If so, enable the feature in the application as all are disabled by default
                    if ($installedPluginsData[$myPluginV]['plugin_enabled']) {
                        //Get the setting to enable this
                        $setting = $myPluginsEnableNew[$myPluginV];
                        \IPS\Settings::i()->changeValues(array($setting => 1));
                    }
                    //Now migrate old settings to new, if there are any
                    if (ISSET($myPluginsMigrateSettings[$myPluginV])) {
                        //We have some settings to migrate
                        foreach ($myPluginsMigrateSettings[$myPluginV] as $settingOld => $settingNew) {
                            //Little something specifically for the "Order databases in 'Create' menu" plugin
                            if ($myPluginV === 'neorderdatabasesincreatemenu' AND $settingOld === 'nepluginorderdatabases_myorder') {
                                $oldSettingValue = \IPS\Settings::i()->nepluginorderdatabases_myorder;
                                if ($oldSettingValue === '') {
                                    \IPS\Settings::i()->changeValues(array($settingNew => \IPS\Settings::i()->$settingOld));
                                } else {
                                    $test = \explode(',', $oldSettingValue);
                                    $newSettingArray = array();
                                    foreach ($test as $testK => $testV) {
                                        $newSettingArray[] = array('key' => $testV, 'value' => $testV);
                                    }
                                    $newSettingValue = \json_encode($newSettingArray);
                                    \IPS\Settings::i()->changeValues(array($settingNew => $newSettingValue));
                                }
                            } else {
                                \IPS\Settings::i()->changeValues(array($settingNew => \IPS\Settings::i()->$settingOld));
                            }
                        }
                    }
                    $toBeDeleted[] = $installedPluginsData[$myPluginV]['plugin_id'];
                }
            }
            if (!empty($toBeDeleted)) {
                //Delete plugin version
                \IPS\Application::load('neappboxoftricks')->enabled = 1;
                \IPS\Application::load('neappboxoftricks')->save();
                \IPS\Task::queue('neappboxoftricks', 'DeleteOldPlugins', $toBeDeleted, 1);
            }
        }
    }

}
