//<?php

/* To prevent PHP errors (extending class does not exist) revealing path */
if (!\defined('\IPS\SUITE_UNIQUE_KEY')) {
    exit;
}

/**
 * @mixin \IPS\core\modules\admin\members\members
 */
class neappboxoftricks_hook_code_core_modules_admin_members extends _HOOK_CLASS_
{
    /**
     * Get the joins for the main table
     *
     * @returns array
     */
    protected static function _getTableJoins(array $joinFields, \IPS\Helpers\Table\Db $table): array
    {
	try
	{
	        $joins = parent::_getTableJoins($joinFields, $table);
	        if (\IPS\Settings::i()->neapp_boxoftricks_settings_enable_loginfilters) {
	            if ($table->filter and str_starts_with($table->filter, 'login_handler_')) {
	                $joins[] = array(
	                    'select' => 'cll.token_login_method',
	                    'from' => array('core_login_links', 'cll'),
	                    'where' => 'cll.token_member=core_members.member_id');
	            }
	        }
	        return $joins;
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }

    /**
     * Get the available filters for the main table
     *
     * @return    array
     */
    protected static function _getTableFilters(): array
    {
	try
	{
	        $filters = parent::_getTableFilters();
	        if (\IPS\Settings::i()->neapp_boxoftricks_settings_enable_loginfilters) {
	            $loginMethods = \IPS\Db::i()->select('*', 'core_login_methods', array('login_enabled=?', 1));
	            foreach ($loginMethods as $k => $v) {
	                if ($v['login_classname'] !== 'IPS\Login\Handler\Standard') {
	                    $filterLabel = $v['login_classname']::getTitle();
	                    $filters[$filterLabel] = "token_login_method = " . $v['login_id'];
	                }
	            }
	        }
	        if (\IPS\Settings::i()->neapp_boxoftricks_settings_enable_mfafilters) {
	            if (\IPS\Settings::i()->verify_enabled) {
	                $filters['mfa_verify_title'] = "mfa_details LIKE '%verify%'";
	            }
	            if (\IPS\Settings::i()->googleauth_enabled) {
	                $filters['mfa_google_title'] = "mfa_details LIKE '%google%'";
	            }
	            if (\IPS\Settings::i()->authy_enabled) {
	                $filters['mfa_authy_title'] = "mfa_details LIKE '%authy%'";
	            }
	        }
	        return $filters;
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }

}
