//<?php
/* To prevent PHP errors (extending class does not exist) revealing path */
if (!\defined('\IPS\SUITE_UNIQUE_KEY')) {
    exit;
}

class neappboxoftricks_hook_code_dispatcher_front extends _HOOK_CLASS_ {

    /**
     * Init
     *
     * @return    void
     * @throws \Exception
     */
    public function init() {
	try
	{
	        if (\IPS\Settings::i()->neapp_boxoftricks_settings_enable_rbu) {
	            if (\IPS\Member::loggedIn()->isBanned()) {
	                \IPS\Output::i()->redirect(\IPS\Settings::i()->neapp_boxoftricks_rbu_redirect_url);
	            }
	        }
	        return parent::init();
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }

    /**
     * Output the basic javascript files every page needs
     *
     * @return void
     */
    protected static function baseJs() {
	try
	{
	        parent::baseJs();
	        if (\IPS\Settings::i()->neapp_boxoftricks_settings_enable_ctvp) {
	            \IPS\Output::i()->jsFiles = array_merge(\IPS\Output::i()->jsFiles, \IPS\Output::i()->js("front_ctvp.js", "neappboxoftricks", "front"));
	            \IPS\Output::i()->jsVars["neapp_boxoftricks_ctvp_edge"] = \IPS\Settings::i()->neapp_boxoftricks_ctvp_edge;
	        }
	        if (\IPS\Settings::i()->neapp_boxoftricks_settings_enable_siteurl AND \IPS\Settings::i()->site_site_elsewhere AND \IPS\Settings::i()->neapp_boxoftricks_siteurl_method === 'js') {
	            \IPS\Output::i()->jsFiles = array_merge(\IPS\Output::i()->jsFiles, \IPS\Output::i()->js("front_siteurl.js", "neappboxoftricks", "front"));
	            \IPS\Output::i()->jsVars["neapp_boxoftricks_siteurl"] = \IPS\Settings::i()->site_main_url;
	        }
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }

    /**
     * Base CSS
     *
     * @return	void
     */
    public static function baseCss() {
	try
	{
	        parent::baseCss();
	        if (\IPS\Settings::i()->neapp_boxoftricks_settings_enable_ctvp) {
	            \IPS\Output::i()->cssFiles = array_merge(\IPS\Output::i()->cssFiles, \IPS\Theme::i()->css('ctvp/ctvp.css', 'neappboxoftricks', 'front'));
	        }
	        if (\IPS\Settings::i()->neapp_boxoftricks_settings_enable_uiffc) {
	            \IPS\Output::i()->cssFiles = array_merge(\IPS\Output::i()->cssFiles, \IPS\Theme::i()->css('uiffc/uiffc.css', 'neappboxoftricks', 'front'));
	        }
	}
	catch ( \Error | \RuntimeException $e )
	{
		if( \defined( '\IPS\DEBUG_HOOKS' ) AND \IPS\DEBUG_HOOKS )
		{
			\IPS\Log::log( $e, 'hook_exception' );
		}

		if ( method_exists( get_parent_class(), __FUNCTION__ ) )
		{
			return \call_user_func_array( 'parent::' . __FUNCTION__, \func_get_args() );
		}
		else
		{
			throw $e;
		}
	}
    }

}
