<?php

namespace IPS\neappboxoftricks\setup\upg_10200;

/* To prevent PHP errors (extending class does not exist) revealing path */
if (!\defined('\IPS\SUITE_UNIQUE_KEY')) {
    header(( isset($_SERVER['SERVER_PROTOCOL']) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden');
    exit;
}

/**
 * 1.2.0 Upgrade Code
 */
class _Upgrade {

    /**
     * ...
     *
     * @return	bool|array 	If returns TRUE, upgrader will proceed to next step. If it returns any other value, it will set this as the value of the 'extra' GET parameter and rerun this step (useful for loops)
     */
    public function step1() {
        $installedPluginsData = iterator_to_array(\IPS\Db::i()->select('plugin_id,plugin_location,plugin_enabled', 'core_plugins', array())->setKeyField('plugin_location'));
        if (\count($installedPluginsData) > 0) {
            $toBeDeleted= array();
            //We have installed plugins...let's check if any are mine!!
            $myPlugins = array(
                'neorderdatabasesincreatemenu'
            );
            //List of specific settings to migrate from plugin version
            $myPluginsMigrateSettings = array(
                'neorderdatabasesincreatemenu' => array(
                    'nepluginorderdatabases_myorder' => 'neapp_boxoftricks_cmsmenu_order'
                )
            );
            $myPluginsEnableNew = array(
                'neorderdatabasesincreatemenu' => 'neapp_boxoftricks_settings_enable_cmsmenu'
            );
            foreach ($myPlugins as $myPluginK => $myPluginV) {
                if (ISSET($installedPluginsData[$myPluginV])) {
                    //We've got one...let's do stuff
                    $insert[] = array(
                        'conf_key' => 'neapp_boxoftricks_settings_enable_cmsmenu',
                        'conf_value' => '',
                        'conf_default' => '',
                        'conf_keywords' => '',
                        'conf_app' => 'neappboxoftricks'
                    );
                    $insert[] = array(
                        'conf_key' => 'neapp_boxoftricks_cmsmenu_order',
                        'conf_value' => '',
                        'conf_default' => '',
                        'conf_keywords' => '',
                        'conf_app' => 'neappboxoftricks'
                    );

                    /* Those keys were added in v1.2.0 so they will not exist so therefore needs to be added by force!!! */
                    \IPS\Db::i()->insert('core_sys_conf_settings', $insert);

                    $setting = '';
                    //Is it enabled? If so, enable the feature in the application as all are disabled by default
                    if ($installedPluginsData[$myPluginV]['plugin_enabled']) {
                        //Get the setting to enable this
                        $setting = $myPluginsEnableNew[$myPluginV];
                        \IPS\Settings::i()->changeValues(array($setting => 1));
                    }
                    //Now migrate old settings to new, if there are any
                    if (ISSET($myPluginsMigrateSettings[$myPluginV])) {
                        //We have some settings to migrate
                        foreach ($myPluginsMigrateSettings[$myPluginV] as $settingOld => $settingNew) {
                            //Little something specifically for the "Order databases in 'Create' menu" plugin
                            if ($myPluginV === 'neorderdatabasesincreatemenu' AND $settingOld === 'nepluginorderdatabases_myorder') {
                                $oldSettingValue = \IPS\Settings::i()->nepluginorderdatabases_myorder;
                                if ($oldSettingValue === '') {
                                    \IPS\Settings::i()->changeValues(array($settingNew => \IPS\Settings::i()->$settingOld));
                                } else {
                                    $test = \explode(',', $oldSettingValue);
                                    $newSettingArray = array();
                                    foreach ($test as $testK => $testV) {
                                        $newSettingArray[] = array('key' => $testV, 'value' => $testV);
                                    }
                                    $newSettingValue = \json_encode($newSettingArray);
                                    \IPS\Settings::i()->changeValues(array($settingNew => $newSettingValue));
                                }
                            } else {
                                \IPS\Settings::i()->changeValues(array($settingNew => \IPS\Settings::i()->$settingOld));
                            }
                        }
                    }
                    $toBeDeleted[] = $installedPluginsData[$myPluginV]['plugin_id'];
                }
            }
            if (!empty($toBeDeleted)) {
                //Delete plugin version
                \IPS\Application::load('neappboxoftricks')->enabled = 1;
                \IPS\Application::load('neappboxoftricks')->save();
                \IPS\Task::queue('neappboxoftricks', 'DeleteOldPlugins', $toBeDeleted, 1);
            }
        }
        return TRUE;
    }

    /**
     * Custom title for this step
     *
     * @return string
     */
    public function step1CustomTitle() {
        return "Checking for plugins added in v1.2.0, migrating their settings and then uninstalling the plugins";
    }

    public function step2() {
        $installedPluginsData = iterator_to_array(\IPS\Db::i()->select('plugin_id,plugin_location,plugin_enabled', 'core_plugins', array())->setKeyField('plugin_location'));
        if (\count($installedPluginsData) > 0) {
            $toBeDeleted= array();
            //We have installed plugins...let's check if any are mine!!
            $myPlugins = array(
                'nememberdeletioncontent'
            );
            //List of specific settings to migrate from plugin version
            $myPluginsMigrateSettings = array(
                'nememberdeletioncontent' => array(
                    'neplugin_member_deletion_content_default' => 'neapp_boxoftricks_mdcd_setting'
                )
            );
            $myPluginsEnableNew = array(
                'nememberdeletioncontent' => 'neapp_boxoftricks_settings_enable_mdcd'
            );
            foreach ($myPlugins as $myPluginK => $myPluginV) {
                if (ISSET($installedPluginsData[$myPluginV])) {
                    //We've got one...let's do stuff
                    $insert[] = array(
                        'conf_key' => 'neapp_boxoftricks_settings_enable_mdcd',
                        'conf_value' => '',
                        'conf_default' => '',
                        'conf_keywords' => '',
                        'conf_app' => 'neappboxoftricks'
                    );
                    $insert[] = array(
                        'conf_key' => 'neapp_boxoftricks_mdcd_setting',
                        'conf_value' => '',
                        'conf_default' => '',
                        'conf_keywords' => '',
                        'conf_app' => 'neappboxoftricks'
                    );

                    /* Those keys were added in v1.2.0 so they will not exist so therefore needs to be added by force!!! */
                    \IPS\Db::i()->insert('core_sys_conf_settings', $insert);

                    $setting = '';
                    //Is it enabled? If so, enable the feature in the application as all are disabled by default
                    if ($installedPluginsData[$myPluginV]['plugin_enabled']) {
                        //Get the setting to enable this
                        $setting = $myPluginsEnableNew[$myPluginV];
                        \IPS\Settings::i()->changeValues(array($setting => 1));
                    }
                    //Now migrate old settings to new, if there are any
                    if (ISSET($myPluginsMigrateSettings[$myPluginV])) {
                        //We have some settings to migrate
                        foreach ($myPluginsMigrateSettings[$myPluginV] as $settingOld => $settingNew) {
                            \IPS\Settings::i()->changeValues(array($settingNew => \IPS\Settings::i()->$settingOld));
                        }
                    }
                    $toBeDeleted[] = $installedPluginsData[$myPluginV]['plugin_id'];
                }
            }
            if (!empty($toBeDeleted)) {
                //Delete plugin version
                \IPS\Application::load('neappboxoftricks')->enabled = 1;
                \IPS\Application::load('neappboxoftricks')->save();
                \IPS\Task::queue('neappboxoftricks', 'DeleteOldPlugins', $toBeDeleted, 1);
            }
        }
        return TRUE;
    }

    /**
     * Custom title for this step
     *
     * @return string
     */
    public function step2CustomTitle() {
        return "Checking for plugins added in v1.2.0, migrating their settings and then uninstalling the plugins";
    }

    public function step3() {
        $installedPluginsData = iterator_to_array(\IPS\Db::i()->select('plugin_id,plugin_location,plugin_enabled', 'core_plugins', array())->setKeyField('plugin_location'));
        if (\count($installedPluginsData) > 0) {
            $toBeDeleted= array();
            //We have installed plugins...let's check if any are mine!!
            $myPlugins = array(
                'nechangecodedefaultlanguage'
            );
            //List of specific settings to migrate from plugin version
            $myPluginsMigrateSettings = array(
                'nechangecodedefaultlanguage' => array(
                    'neplugin_codedefault_language' => 'neapp_boxoftricks_ccdl_default'
                )
            );
            $myPluginsEnableNew = array(
                'nechangecodedefaultlanguage' => 'neapp_boxoftricks_settings_enable_ccdl'
            );
            foreach ($myPlugins as $myPluginK => $myPluginV) {
                if (ISSET($installedPluginsData[$myPluginV])) {
                    //We've got one...let's do stuff
                    $insert[] = array(
                        'conf_key' => 'neapp_boxoftricks_settings_enable_ccdl',
                        'conf_value' => '',
                        'conf_default' => '',
                        'conf_keywords' => '',
                        'conf_app' => 'neappboxoftricks'
                    );
                    $insert[] = array(
                        'conf_key' => 'neapp_boxoftricks_ccdl_default',
                        'conf_value' => '',
                        'conf_default' => '',
                        'conf_keywords' => '',
                        'conf_app' => 'neappboxoftricks'
                    );

                    /* Those keys were added in v1.2.0 so they will not exist so therefore needs to be added by force!!! */
                    \IPS\Db::i()->insert('core_sys_conf_settings', $insert);

                    $setting = '';
                    //Is it enabled? If so, enable the feature in the application as all are disabled by default
                    if ($installedPluginsData[$myPluginV]['plugin_enabled']) {
                        //Get the setting to enable this
                        $setting = $myPluginsEnableNew[$myPluginV];
                        \IPS\Settings::i()->changeValues(array($setting => 1));
                    }
                    //Now migrate old settings to new, if there are any
                    if (ISSET($myPluginsMigrateSettings[$myPluginV])) {
                        //We have some settings to migrate
                        foreach ($myPluginsMigrateSettings[$myPluginV] as $settingOld => $settingNew) {
                            \IPS\Settings::i()->changeValues(array($settingNew => \IPS\Settings::i()->$settingOld));
                        }
                    }
                    $toBeDeleted[] = $installedPluginsData[$myPluginV]['plugin_id'];
                }
            }
            if (!empty($toBeDeleted)) {
                //Delete plugin version
                \IPS\Application::load('neappboxoftricks')->enabled = 1;
                \IPS\Application::load('neappboxoftricks')->save();
                \IPS\Task::queue('neappboxoftricks', 'DeleteOldPlugins', $toBeDeleted, 1);
            }
        }
        return TRUE;
    }

    /**
     * Custom title for this step
     *
     * @return string
     */
    public function step3CustomTitle() {
        return "Checking for plugins added in v1.2.0, migrating their settings and then uninstalling the plugins";
    }

    // You can create as many additional methods (step2, step3, etc.) as is necessary.
    // Each step will be executed in a new HTTP request
}
