<?php

namespace IPS\neappboxoftricks\setup\upg_10400;

/* To prevent PHP errors (extending class does not exist) revealing path */
if (!\defined('\IPS\SUITE_UNIQUE_KEY')) {
    header(( isset($_SERVER['SERVER_PROTOCOL']) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden');
    exit;
}

/**
 * 1.4.0 Upgrade Code
 */
class _Upgrade {

    /**
     * ...
     *
     * @return	bool|array 	If returns TRUE, upgrader will proceed to next step. If it returns any other value, it will set this as the value of the 'extra' GET parameter and rerun this step (useful for loops)
     */
    public function step1() {
        $installedPluginsData = iterator_to_array(\IPS\Db::i()->select('plugin_id,plugin_location,plugin_enabled', 'core_plugins', array())->setKeyField('plugin_location'));
        if (\count($installedPluginsData) > 0) {
            $toBeDeleted = array();
            //We have installed plugins...let's check if any are mine!!
            $myPlugins = array(
                'nesiteurl'
            );
            $myPluginsEnableNew = array(
                'nesiteurl' => 'neapp_boxoftricks_settings_enable_siteurl'
            );
            foreach ($myPlugins as $myPluginK => $myPluginV) {
                if (ISSET($installedPluginsData[$myPluginV])) {
                    //We've got one...let's do stuff
                    $insert[] = array(
                        'conf_key' => 'neapp_boxoftricks_settings_enable_siteurl',
                        'conf_value' => '',
                        'conf_default' => '',
                        'conf_keywords' => '',
                        'conf_app' => 'neappboxoftricks'
                    );
                    /* Those keys were added in v1.2.0 so they will not exist so therefore needs to be added by force!!! */
                    \IPS\Db::i()->insert('core_sys_conf_settings', $insert);

                    $setting = '';
                    //Is it enabled? If so, enable the feature in the application as all are disabled by default
                    if ($installedPluginsData[$myPluginV]['plugin_enabled']) {
                        //Get the setting to enable this
                        $setting = $myPluginsEnableNew[$myPluginV];
                        \IPS\Settings::i()->changeValues(array($setting => 1));
                    }
                    $toBeDeleted[] = $installedPluginsData[$myPluginV]['plugin_id'];
                }
            }
            if (!empty($toBeDeleted)) {
                //Delete plugin version
                \IPS\Application::load('neappboxoftricks')->enabled = 1;
                \IPS\Application::load('neappboxoftricks')->save();
                \IPS\Task::queue('neappboxoftricks', 'DeleteOldPlugins', $toBeDeleted, 1);
            }
        }
        return TRUE;
    }

    /**
     * Custom title for this step
     *
     * @return string
     */
    public function step1CustomTitle() {
        return "Checking for plugins added in v1.4.0, migrating their settings and then uninstalling the plugins";
    }

}
