<?php

namespace IPS\neappboxoftricks;

/* To prevent PHP errors (extending class does not exist) revealing path */
if (!\defined('\IPS\SUITE_UNIQUE_KEY')) {
    header(( isset($_SERVER['SERVER_PROTOCOL']) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden');
    exit;
}

class _Forms {

    public function createForm() {
        $form = new \IPS\Helpers\Form;
        static::checkEnabledPlugins();
        static::showEnableSettings($form);
        static::mdcdSettings($form);
        static::ccdlSettings($form);
        static::ctvpSettings($form);
        static::ichppSettings($form);
        static::mcnspSettings($form);
        static::oaaadsSettings($form);
        static::siteurlSettings($form);
        if (\in_array('forums', array_keys(\IPS\Application::applications())) AND \IPS\Application::appIsEnabled('forums')) {
            static::uiffcSettings($form);
        }
        if (\in_array('cms', array_keys(\IPS\Application::applications())) AND \IPS\Application::appIsEnabled('cms')) {
            //A little check here to see if they have more than one database...it's pointless showing this setting if they don't
            $cmsDatabases = \IPS\cms\Databases::databases();
            if (\count($cmsDatabases) > 1) {
                static::cmsmenuSettings($form);
            }
        }
        if (\in_array('cms', array_keys(\IPS\Application::applications())) AND \IPS\Application::appIsEnabled('cms')) {
            static::cmsmediatypeSettings($form);
        }
        return $form;
    }

    public function processForm(array $values) {
        if (\in_array('cms', array_keys(\IPS\Application::applications())) AND \IPS\Application::appIsEnabled('cms')) {
            $cmsDatabases = \IPS\cms\Databases::databases();
            if (\count($cmsDatabases) > 1) {
                if ($values['neapp_boxoftricks_settings_enable_cmsmenu']) {
                    $values['neapp_boxoftricks_cmsmenu_order'] = \json_encode($values['neapp_boxoftricks_cmsmenu_order']);
                } else {
                    UNSET($values['neapp_boxoftricks_cmsmenu_order']);
                }
            }
            if ($values['neapp_boxoftricks_settings_enable_cmsmediatype']) {
                if (!$values['neapp_boxoftricks_cmsmediatype_all']) {
                    $values['neapp_boxoftricks_cmsmediatype_extra'] = \implode(',', $values['neapp_boxoftricks_cmsmediatype_extra']);
                } else {
                    UNSET($values['neapp_boxoftricks_cmsmediatype_extra']);
                }
            } else {
                UNSET($values['neapp_boxoftricks_cmsmediatype_extra']);
            }
        }
        if ($values['neapp_boxoftricks_settings_enable_ichpp']) {
            $values['neapp_boxoftricks_ichpp_groups'] = $values['neapp_boxoftricks_ichpp_groups'] === '*' ? $values['neapp_boxoftricks_ichpp_groups'] : \json_encode($values['neapp_boxoftricks_ichpp_groups']);
        } else {
            UNSET($values['neapp_boxoftricks_ichpp_groups']);
        }
        if ($values['neapp_boxoftricks_settings_enable_mcnsp']) {
            $values['neapp_boxoftricks_mcnsp_groups'] = $values['neapp_boxoftricks_mcnsp_groups'] === '*' ? $values['neapp_boxoftricks_mcnsp_groups'] : \json_encode($values['neapp_boxoftricks_mcnsp_groups']);
        } else {
            UNSET($values['neapp_boxoftricks_mcnsp_groups']);
        }
        if (ISSET($values['neapp_boxoftricks_ctvp_account']) AND $values['neapp_boxoftricks_ctvp_account']) {
            //Check if any of the 2 sub-settings are enabled - if neither are, what's the point of leaving this one enabled?
            if (!$values['neapp_boxoftricks_ctvp_account_password'] AND !$values['neapp_boxoftricks_ctvp_account_privacy']) {
                $values['neapp_boxoftricks_ctvp_account'] = false;
            }
        }
        return $values;
    }

    protected static function checkEnabledPlugins() {
        $checkPlugins = array(
            'neclicktoviewpassword' => 'neapp_boxoftricks_settings_enable_ctvp_warning',
            'neviewpasswordonstandardlogin' => 'neapp_boxoftricks_settings_enable_ctvp_warning',
            'neicanhazprofilephotonothamburger' => 'neapp_boxoftricks_settings_enable_ichpp_warning',
            'neoverrideallactivityasdefaultstream' => 'neapp_boxoftricks_settings_enable_oaaads_warning',
            'neunreadiconforforumcategories' => 'neapp_boxoftricks_settings_enable_uiffc_warning',
            'neuse_development_buildsreminder' => 'neapp_boxoftricks_settings_enable_udbr_warning',
            'nemanagecreatenewstreampermissions' => 'neapp_boxoftricks_settings_enable_mcnsp_warning',
            'neorderdatabasesincreatemenu' => 'neapp_boxoftricks_settings_enable_cmsmenu_warning',
            'nememberdeletioncontent' => 'neapp_boxoftricks_settings_enable_mdcd_warning',
            'nechangecodedefaultlanguage' => 'neapp_boxoftricks_settings_enable_ccdl_warning',
            'neadditionalpagesmediatypes' => 'neapp_boxoftricks_settings_enable_cmsmediatype',
            'nesiteurl' => 'neapp_boxoftricks_settings_enable_siteurl'
        );
        $plugins = \IPS\Plugin::enabledPlugins();
        foreach (\IPS\Plugin::enabledPlugins() as $k => $v) {
            if (ISSET($checkPlugins[$v->location])) {
                \IPS\Member::loggedIn()->language()->words[$checkPlugins[$v->location]] = \IPS\Member::loggedIn()->language()->get('neapp_boxoftricks_plugin_enabled');
            }
        }
    }

    protected static function showEnableSettings($form) {
        \IPS\Member::loggedIn()->language()->words['neapp_boxoftricks_settings_enable_ctvp_desc'] = \IPS\Member::loggedIn()->language()->get('neapp_boxoftricks_settings_enable_information');
        \IPS\Member::loggedIn()->language()->words['neapp_boxoftricks_settings_enable_ichpp_desc'] = \IPS\Member::loggedIn()->language()->get('neapp_boxoftricks_settings_enable_information');
        \IPS\Member::loggedIn()->language()->words['neapp_boxoftricks_settings_enable_mcnsp_desc'] = \IPS\Member::loggedIn()->language()->get('neapp_boxoftricks_settings_enable_information');
        \IPS\Member::loggedIn()->language()->words['neapp_boxoftricks_settings_enable_oaaads_desc'] = \IPS\Member::loggedIn()->language()->get('neapp_boxoftricks_settings_enable_information');
        \IPS\Member::loggedIn()->language()->words['neapp_boxoftricks_settings_enable_ccdl_desc'] = \IPS\Member::loggedIn()->language()->get('neapp_boxoftricks_settings_enable_information');
        \IPS\Member::loggedIn()->language()->words['neapp_boxoftricks_settings_enable_mdcd_desc'] = \IPS\Member::loggedIn()->language()->get('neapp_boxoftricks_settings_enable_information');
        \IPS\Member::loggedIn()->language()->words['neapp_boxoftricks_settings_enable_siteurl_desc'] = \IPS\Member::loggedIn()->language()->get('neapp_boxoftricks_settings_enable_information');
        $form->addTab('neapp_boxoftricks_settings_tabs_enable');
        $form->addHeader('neapp_boxoftricks_settings_header_core_acp');
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_loginfilters', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_loginfilters, FALSE, array()));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_lcount', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_lcount, FALSE, array()));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_mdcd', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_mdcd, FALSE, array('togglesOn' => array("{$form->id}_tab_neapp_boxoftricks_settings_tabs_mdcd"))));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_mfafilters', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_mfafilters, FALSE, array()));
        if (!\IPS\CIC) {
            $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_udbr', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_udbr, FALSE, array()));
        }
        $form->addHeader('neapp_boxoftricks_settings_header_core_front');
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_ccdl', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_ccdl, FALSE, array('togglesOn' => array("{$form->id}_tab_neapp_boxoftricks_settings_tabs_ccdl"))));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_ctvp', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_ctvp, FALSE, array('togglesOn' => array("{$form->id}_tab_neapp_boxoftricks_settings_tabs_ctvp"))));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_hideads', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_hideads, FALSE, array('togglesOn' => array("{$form->id}_tab_neapp_boxoftricks_settings_tabs_hideads"))));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_ichpp', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_ichpp, FALSE, array('togglesOn' => array("{$form->id}_tab_neapp_boxoftricks_settings_tabs_ichpp"))));
        if (\IPS\Settings::i()->site_site_elsewhere) {
            $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_siteurl', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_siteurl, FALSE, array('togglesOn' => array("{$form->id}_tab_neapp_boxoftricks_settings_tabs_siteurl"))));
        }
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_mcnsp', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_mcnsp, FALSE, array('togglesOn' => array("{$form->id}_tab_neapp_boxoftricks_settings_tabs_mcnsp"))));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_oaaads', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_oaaads, FALSE, array('togglesOn' => array("{$form->id}_tab_neapp_boxoftricks_settings_tabs_oaaads"))));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_rnfns', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_rnfns, FALSE, array()));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_rmor', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_rmor, FALSE, array()));
        if (\in_array('forums', array_keys(\IPS\Application::applications())) AND \IPS\Application::appIsEnabled('forums')) {
            $form->addHeader('__app_forums');
            \IPS\Member::loggedIn()->language()->words['neapp_boxoftricks_settings_enable_uiffc_desc'] = \IPS\Member::loggedIn()->language()->get('neapp_boxoftricks_settings_enable_information');
            $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_uiffc', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_uiffc, FALSE, array('togglesOn' => array("{$form->id}_tab_neapp_boxoftricks_settings_tabs_uiffc"))));
        }
        if (\in_array('cms', array_keys(\IPS\Application::applications())) AND \IPS\Application::appIsEnabled('cms')) {
            $form->addHeader('__app_cms');
            \IPS\Member::loggedIn()->language()->words['neapp_boxoftricks_settings_enable_cmsmediatype_desc'] = \IPS\Member::loggedIn()->language()->get('neapp_boxoftricks_settings_enable_information');
            $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_cmsmediatype', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_cmsmediatype, FALSE, array('togglesOn' => array("{$form->id}_tab_neapp_boxoftricks_settings_tabs_cmsmediatype"))));
            //A little check here to see if they have more than one database...pointless showing this setting if they only have one
            $cmsDatabases = \IPS\cms\Databases::databases();
            if (\count($cmsDatabases) > 1) {
                \IPS\Member::loggedIn()->language()->words['neapp_boxoftricks_settings_enable_cmsmenu_desc'] = \IPS\Member::loggedIn()->language()->get('neapp_boxoftricks_settings_enable_information');
                $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_settings_enable_cmsmenu', \IPS\Settings::i()->neapp_boxoftricks_settings_enable_cmsmenu, FALSE, array('togglesOn' => array("{$form->id}_tab_neapp_boxoftricks_settings_tabs_cmsmenu"))));
            }
        }
        return $form;
    }

    protected static function ccdlSettings($form) {
        $form->addTab('neapp_boxoftricks_settings_tabs_ccdl');
        $options = array(
            'null' => 'editor_code_null',
            'c' => 'C Languages (C, C++, C#, Java, Objective C)',
            'css' => 'editor_code_css',
            'html' => 'editor_code_htmlmixed',
            'javascript' => 'editor_code_javascript',
            'lua' => 'Lua',
            'perl' => 'Perl',
            'php' => 'editor_code_php',
            'py' => 'Python',
            'ruby' => 'Ruby',
            'sql' => 'editor_code_sql',
            'latex' => 'StEx/LaTeX',
            'swift' => 'Swift',
            'xml' => 'editor_code_xml',
        );
        $form->add(new \IPS\Helpers\Form\Select('neapp_boxoftricks_ccdl_default', \IPS\Settings::i()->neapp_boxoftricks_ccdl_default, FALSE, array('options' => $options)));
        return $form;
    }

    protected static function ctvpSettings($form) {
        $form->addTab('neapp_boxoftricks_settings_tabs_ctvp');
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_ctvp_edge', \IPS\Settings::i()->neapp_boxoftricks_ctvp_edge));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_ctvp_login', \IPS\Settings::i()->neapp_boxoftricks_ctvp_login));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_ctvp_register', \IPS\Settings::i()->neapp_boxoftricks_ctvp_register));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_ctvp_mfa', \IPS\Settings::i()->neapp_boxoftricks_ctvp_mfa));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_ctvp_forum', \IPS\Settings::i()->neapp_boxoftricks_ctvp_forum));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_ctvp_account', \IPS\Settings::i()->neapp_boxoftricks_ctvp_account, FALSE, array('togglesOn' => array('neapp_boxoftricks_ctvp_account_privacy', 'neapp_boxoftricks_ctvp_account_password'))));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_ctvp_account_password', \IPS\Settings::i()->neapp_boxoftricks_ctvp_account_password, FALSE, array(), NULL, NULL, NULL, 'neapp_boxoftricks_ctvp_account_password'));
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_ctvp_account_privacy', \IPS\Settings::i()->neapp_boxoftricks_ctvp_account_privacy, FALSE, array(), NULL, NULL, NULL, 'neapp_boxoftricks_ctvp_account_privacy'));
        if (\in_array('tpp', array_keys(\IPS\Application::applications())) AND \IPS\Application::appIsEnabled('tpp')) {
            $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_ctvp_tpp', \IPS\Settings::i()->neapp_boxoftricks_ctvp_tpp));
        }
        return $form;
    }

    protected static function ichppSettings($form) {
        $form->addTab('neapp_boxoftricks_settings_tabs_ichpp');
        $form->add(new \IPS\Helpers\Form\Select('neapp_boxoftricks_ichpp_groups', (\IPS\Settings::i()->neapp_boxoftricks_ichpp_groups === '*' ? '*' : (\is_array(\IPS\Settings::i()->neapp_boxoftricks_ichpp_groups) ? \IPS\Settings::i()->neapp_boxoftricks_ichpp_groups : \json_decode(\IPS\Settings::i()->neapp_boxoftricks_ichpp_groups, TRUE))), FALSE, array('options' => \IPS\Member\Group::groups(TRUE, FALSE), 'parse' => 'normal', 'multiple' => TRUE, 'unlimited' => '*', 'unlimitedLang' => 'All Groups')));
        return $form;
    }

    protected static function mcnspSettings($form) {
        $form->addTab('neapp_boxoftricks_settings_tabs_mcnsp');
        $form->add(new \IPS\Helpers\Form\Select('neapp_boxoftricks_mcnsp_groups', (\IPS\Settings::i()->neapp_boxoftricks_mcnsp_groups === '*' ? '*' : (\is_array(\IPS\Settings::i()->neapp_boxoftricks_mcnsp_groups) ? \IPS\Settings::i()->neapp_boxoftricks_mcnsp_groups : \json_decode(\IPS\Settings::i()->neapp_boxoftricks_mcnsp_groups, TRUE))), FALSE, array('options' => \IPS\Member\Group::groups(true, false), 'parse' => 'normal', 'multiple' => TRUE, 'unlimited' => '*', 'unlimitedLang' => 'All Groups')));
        return $form;
    }

    protected static function cmsmenuSettings($form) {
        $form->addTab('neapp_boxoftricks_settings_tabs_cmsmenu');
        $cmsmenuDatabases = \IPS\cms\Databases::databases();
        $new = array();
        if (\IPS\Settings::i()->neapp_boxoftricks_cmsmenu_order !== '' OR \IPS\Settings::i()->neapp_boxoftricks_cmsmenu_order !== '[]') {
            if (!\is_null(\IPS\Settings::i()->neapp_boxoftricks_cmsmenu_order)) {
                $myOrder = \is_array(\IPS\Settings::i()->neapp_boxoftricks_cmsmenu_order) ? \IPS\Settings::i()->neapp_boxoftricks_cmsmenu_order : json_decode(\IPS\Settings::i()->neapp_boxoftricks_cmsmenu_order, TRUE);
                //Quick loop through the existing order to see if there are any databases that no longer exist
                foreach ($myOrder as $k => $v) {
                    if (!ISSET($cmsmenuDatabases[$v['key']])) {
                        UNSET($myOrder[$k]);
                    }
                }
            }
        }
        //Now a loop through the databases to see if one has been added to the mix
        foreach ($cmsmenuDatabases as $k => $v) {
            if (\IPS\Settings::i()->neapp_boxoftricks_cmsmenu_order === '' OR \IPS\Settings::i()->neapp_boxoftricks_cmsmenu_order === '[]' OR \is_null(\IPS\Settings::i()->neapp_boxoftricks_cmsmenu_order)) {
                $stuff[] = array(
                    'key' => (string) $k,
                    'value' => true
                );
            } else {
                $stuff = $myOrder;
                $keys = array_column($myOrder, 'key');
                $found_key = array_search($k, $keys);
                if (!\is_numeric($found_key) AND !$found_key) {
                    $new[] = array(
                        'key' => (string) $k,
                        'value' => ''
                    );
                }
            }
        }
        $stuff = array_merge($stuff, $new);
        $form->add(new \IPS\Helpers\Form\Stack('neapp_boxoftricks_cmsmenu_order', $stuff, FALSE, array('stackFieldType' => '\IPS\neappboxoftricks\Form\CmsMenuReorder', 'maxItems' => \count($cmsmenuDatabases), 'key' => array('size' => 20))));
        return $form;
    }

    protected static function cmsmediatypeSettings($form) {
        $form->addTab('neapp_boxoftricks_settings_tabs_cmsmediatype');
        $form->add(new \IPS\Helpers\Form\YesNo('neapp_boxoftricks_cmsmediatype_all', \IPS\Settings::i()->neapp_boxoftricks_cmsmediatype_all, FALSE, array('togglesOff' => array('neapp_boxoftricks_cmsmediatype_extra')), NULL, NULL, NULL, 'neapp_boxoftricks_cmsmediatype_all'));
        $form->add(new \IPS\Helpers\Form\Text('neapp_boxoftricks_cmsmediatype_extra', \IPS\Settings::i()->neapp_boxoftricks_cmsmediatype_extra ? explode(',', \IPS\Settings::i()->neapp_boxoftricks_cmsmediatype_extra) : NULL, FALSE, array('autocomplete' => array('freeChoice' => TRUE)), NULL, NULL, NULL, 'neapp_boxoftricks_cmsmediatype_extra'));
        return $form;
    }

    protected static function mdcdSettings($form) {
        $form->addTab('neapp_boxoftricks_settings_tabs_mdcd');
        $form->add(new \IPS\Helpers\Form\Radio('neapp_boxoftricks_mdcd_setting', \IPS\Settings::i()->neapp_boxoftricks_mdcd_setting, FALSE, array('options' => array('delete' => 'delete_content', 'hide' => 'hide_content', 'leave' => 'leave_content'))));
        return $form;
    }

    protected static function oaaadsSettings($form) {
        $form->addTab('neapp_boxoftricks_settings_tabs_oaaads');
        $oaaadsOptions = array();
        $oaaadsStreams = \IPS\core\Stream::roots();
        foreach ($oaaadsStreams as $k => $v) {
            $oaaadsOptions[$k] = $v->_title;
        }
        $form->add(new \IPS\Helpers\Form\Select('neapp_boxoftricks_oaaads_homepage', \IPS\Settings::i()->neapp_boxoftricks_oaaads_homepage, false, array('options' => $oaaadsOptions), NULL, NULL, NULL, 'neapp_boxoftricks_oaaads_homepage'));
        return $form;
    }

    protected static function uiffcSettings($form) {
        $form->addTab('neapp_boxoftricks_settings_tabs_uiffc');
        $form->add(new \IPS\Helpers\Form\Select('neapp_boxoftricks_uiffc_icon_location', \IPS\Settings::i()->neapp_boxoftricks_uiffc_icon_location, FALSE, array('options' => array(0 => 'neapp_boxoftricks_uiffc_icon_location_0', 1 => 'neapp_boxoftricks_uiffc_icon_location_1'))));
        return $form;
    }

    protected static function siteurlSettings($form) {
        if (\IPS\Settings::i()->site_site_elsewhere) {
            $form->addTab('neapp_boxoftricks_settings_tabs_siteurl');
            $form->add(new \IPS\Helpers\Form\Select('neapp_boxoftricks_siteurl_method', \IPS\Settings::i()->neapp_boxoftricks_siteurl_method, FALSE, array('options' => array('js' => 'neapp_boxoftricks_siteurl_method_js', 'template' => 'neapp_boxoftricks_siteurl_method_template'))));
        }
        return $form;
    }

}
